@@ -41,11 +41,11 @@ class CPPA3TestCase( unittest.TestCase ):
         bcpp =  lxml.etree.parse(cppb_file)
         if self.schema != None:
             if self.schema.validate(acpp) and self.schema.validate(bcpp):
-                unifier = cppa3.unify.CPABuilder()
+                pass
             else:
                 err = str(self.schema.error_log.last_error)
                 raise cppa3.unify.UnificationException('Invalid input: {}'.format(err))
-        cpa = unifier.unify(acpp, bcpp)
+        cpa = unify(acpp, bcpp)
         if self.schema != None and self.schema.validate(cpa):
             logging.error('CPA {} is invalid'.format(id))
             raise cppa3.unify.UnificationException('CPA {} is invalid'.format(id))
